@@ -32,7 +32,7 @@
 #include <tools/resmgr.hxx>
 #include <svl/solar.hrc>
 #include <comphelper/sequence.hxx>
-#include <tools/debug.hxx>
+#include <osl/diagnose.h>
 
 #define ENTER_MOD_METHOD()	\
     ::osl::MutexGuard aGuard(s_aMutex);	\
@@ -90,12 +90,12 @@ namespace COMPMOD_NAMESPACE
         // note that this method is not threadsafe, which counts for the whole class !
         if (!m_pRessources && !m_bInitialized)
         {
-            DBG_ASSERT(m_sFilePrefix.Len(), "OModuleImpl::getResManager: no resource file prefix!");
+            OSL_ENSURE(m_sFilePrefix.Len(), "OModuleImpl::getResManager: no resource file prefix!");
             // create a manager with a fixed prefix
             ByteString aMgrName = m_sFilePrefix;
 
             m_pRessources = ResMgr::CreateResMgr(aMgrName.GetBuffer());
-            DBG_ASSERT(m_pRessources, 
+            OSL_ENSURE(m_pRessources,
                     (ByteString("OModuleImpl::getResManager: could not create the resource manager (file name: ")
                 +=	aMgrName
                 +=	ByteString(")!")).GetBuffer());
@@ -205,7 +205,7 @@ namespace COMPMOD_NAMESPACE
     {
         if (!s_pImplementationNames)
         {
-            OSL_ASSERT("OModule::revokeComponent : have no class infos ! Are you sure called this method at the right time ?");
+            OSL_FAIL("OModule::revokeComponent : have no class infos ! Are you sure called this method at the right time ?");
             return;
         }
         OSL_ENSURE(s_pImplementationNames && s_pSupportedServices && s_pCreationFunctionPointers && s_pFactoryFunctionPointers,
@@ -238,54 +238,6 @@ namespace COMPMOD_NAMESPACE
         }
     }
 
-    //--------------------------------------------------------------------------
-    sal_Bool OModule::writeComponentInfos(
-            const Reference< XMultiServiceFactory >& /*_rxServiceManager*/,
-            const Reference< XRegistryKey >& _rxRootKey)
-    {
-        OSL_ENSURE(_rxRootKey.is(), "OModule::writeComponentInfos : invalid argument !");
-
-        if (!s_pImplementationNames)
-        {
-            OSL_ASSERT("OModule::writeComponentInfos : have no class infos ! Are you sure called this method at the right time ?");
-            return sal_True;
-        }
-        OSL_ENSURE(s_pImplementationNames && s_pSupportedServices && s_pCreationFunctionPointers && s_pFactoryFunctionPointers,
-            "OModule::writeComponentInfos : inconsistent state (the pointers) !");
-        OSL_ENSURE(	(s_pImplementationNames->getLength() == s_pSupportedServices->getLength())
-                    &&	(s_pImplementationNames->getLength() == s_pCreationFunctionPointers->getLength())
-                    &&	(s_pImplementationNames->getLength() == s_pFactoryFunctionPointers->getLength()),
-            "OModule::writeComponentInfos : inconsistent state !");
-
-        sal_Int32 nLen = s_pImplementationNames->getLength();
-        const ::rtl::OUString* pImplName = s_pImplementationNames->getConstArray();
-        const Sequence< ::rtl::OUString >* pServices = s_pSupportedServices->getConstArray();
-
-        ::rtl::OUString sRootKey("/", 1, RTL_TEXTENCODING_ASCII_US);
-        for (sal_Int32 i=0; i<nLen; ++i, ++pImplName, ++pServices)
-        {
-            ::rtl::OUString aMainKeyName(sRootKey);
-            aMainKeyName += *pImplName;
-            aMainKeyName += ::rtl::OUString::createFromAscii("/UNO/SERVICES");
-
-            try
-            {
-                Reference< XRegistryKey >  xNewKey( _rxRootKey->createKey(aMainKeyName) );
-
-                const ::rtl::OUString* pService = pServices->getConstArray();
-                for (sal_Int32 j=0; j<pServices->getLength(); ++j, ++pService)
-                    xNewKey->createKey(*pService);
-            }
-            catch(Exception&)
-            {
-                OSL_ASSERT("OModule::writeComponentInfos : something went wrong while creating the keys !");
-                return sal_False;
-            }
-        }
-
-        return sal_True;
-    }
-
     //--------------------------------------------------------------------------
     Reference< XInterface > OModule::getComponentFactory(
         const ::rtl::OUString& _rImplementationName,
@@ -296,7 +248,7 @@ namespace COMPMOD_NAMESPACE
 
         if (!s_pImplementationNames)
         {
-            OSL_ASSERT("OModule::getComponentFactory : have no class infos ! Are you sure called this method at the right time ?");
+            OSL_FAIL("OModule::getComponentFactory : have no class infos ! Are you sure called this method at the right time ?");
             return NULL;
         }
         OSL_ENSURE(s_pImplementationNames && s_pSupportedServices && s_pCreationFunctionPointers && s_pFactoryFunctionPointers,
