@@ -38,7 +38,7 @@
 #include <toolkit/helper/convert.hxx>
 #include "RptPage.hxx"
 #include "corestrings.hrc"
-#include <dbaccess/singledoccontroller.hxx>
+#include <dbaccess/dbsubcomponentcontroller.hxx>
 #include "ModuleHelper.hxx"
 
 #include <RptResId.hrc>
@@ -172,7 +172,7 @@ SdrObject* OObjectBase::createObject(const uno::Reference< report::XReportCompon
             pNewObj = OOle2Obj::Create( _xComponent,nType );
             break;
         default:
-            OSL_ENSURE(0,"Unknown object id");
+            OSL_FAIL("Unknown object id");
             break;
     }
 
@@ -205,9 +205,9 @@ namespace
                         nTextAlign = style::ParagraphAdjust_RIGHT;
                         break;
                     default:
-                        OSL_ENSURE(0,"Illegal text alignment value!");
+                        OSL_FAIL("Illegal text alignment value!");
                         break;
-                } // switch(nTextAlign)
+                }
                 aRet <<= (style::ParagraphAdjust)nTextAlign;
             }
             else
@@ -228,9 +228,9 @@ namespace
                         nTextAlign = awt::TextAlign::RIGHT;
                         break;
                     default:
-                        OSL_ENSURE(0,"Illegal text alignment value!");
+                        OSL_FAIL("Illegal text alignment value!");
                         break;
-                } // switch(eParagraphAdjust)
+                }
                 aRet <<= nTextAlign;
             }
             return aRet;
@@ -251,7 +251,6 @@ const TPropertyNamePair& getPropertyNameMap(sal_uInt16 _nObjectId)
                     s_aNameMap.insert(TPropertyNamePair::value_type(PROPERTY_CONTROLBACKGROUND,TPropertyConverter(PROPERTY_BACKGROUNDCOLOR,aNoConverter)));
                     s_aNameMap.insert(TPropertyNamePair::value_type(PROPERTY_CONTROLBORDER,TPropertyConverter(PROPERTY_BORDER,aNoConverter)));
                     s_aNameMap.insert(TPropertyNamePair::value_type(PROPERTY_CONTROLBORDERCOLOR,TPropertyConverter(PROPERTY_BORDERCOLOR,aNoConverter)));
-                    //s_aNameMap.insert(TPropertyNamePair::value_type(PROPERTY_PARAADJUST,PROPERTY_ALIGN));
                 }
                 return s_aNameMap;
             }
@@ -292,7 +291,6 @@ const TPropertyNamePair& getPropertyNameMap(sal_uInt16 _nObjectId)
                     s_aNameMap.insert(TPropertyNamePair::value_type(PROPERTY_CONTROLTEXTEMPHASISMARK,TPropertyConverter(PROPERTY_FONTEMPHASISMARK,aNoConverter)));
                     s_aNameMap.insert(TPropertyNamePair::value_type(PROPERTY_CONTROLBORDER,TPropertyConverter(PROPERTY_BORDER,aNoConverter)));
                     s_aNameMap.insert(TPropertyNamePair::value_type(PROPERTY_CONTROLBORDERCOLOR,TPropertyConverter(PROPERTY_BORDERCOLOR,aNoConverter)));
-                    //s_aNameMap.insert(TPropertyNamePair::value_type(PROPERTY_PARAADJUST,TPropertyConverter(PROPERTY_ALIGN,aNoConverter)));
                     ::boost::shared_ptr<AnyConverter> aParaAdjust(new ParaAdjust());
                     s_aNameMap.insert(TPropertyNamePair::value_type(PROPERTY_PARAADJUST,TPropertyConverter(PROPERTY_ALIGN,aParaAdjust)));
                 }
@@ -398,7 +396,7 @@ void OObjectBase::EndListening(sal_Bool /*bRemoveListener*/)
             }
             catch(uno::Exception)
             {
-                OSL_ENSURE(0,"OObjectBase::EndListening: Exception caught!");
+                OSL_FAIL("OObjectBase::EndListening: Exception caught!");
             }
         }
         m_xPropertyChangeListener.clear();
@@ -510,12 +508,12 @@ OCustomShape::~OCustomShape()
     DBG_DTOR( rpt_OCustomShape, NULL);
 }
 // -----------------------------------------------------------------------------
-UINT16 OCustomShape::GetObjIdentifier() const
+sal_uInt16 OCustomShape::GetObjIdentifier() const
 {
-    return UINT16(OBJ_CUSTOMSHAPE);
+    return sal_uInt16(OBJ_CUSTOMSHAPE);
 }
 //----------------------------------------------------------------------------
-UINT32 OCustomShape::GetObjInventor() const
+sal_uInt32 OCustomShape::GetObjInventor() const
 {
     return ReportInventor;
 }
@@ -534,7 +532,7 @@ sal_Int32 OCustomShape::GetStep() const
 {
     // get step property
     sal_Int32 nStep = 0;
-    OSL_ENSURE(0,"Who called me!");
+    OSL_FAIL("Who called me!");
     return nStep;
 }
 //----------------------------------------------------------------------------
@@ -693,12 +691,12 @@ void OUnoObject::impl_setReportComponent_nothrow()
     impl_initializeModel_nothrow();
 }
 // -----------------------------------------------------------------------------
-UINT16 OUnoObject::GetObjIdentifier() const
+sal_uInt16 OUnoObject::GetObjIdentifier() const
 {
-    return UINT16(m_nObjectType);
+    return sal_uInt16(m_nObjectType);
 }
 //----------------------------------------------------------------------------
-UINT32 OUnoObject::GetObjInventor() const
+sal_uInt32 OUnoObject::GetObjInventor() const
 {
     return ReportInventor;
 }
@@ -720,7 +718,7 @@ sal_Int32 OUnoObject::GetStep() const
     DBG_CHKTHIS( rpt_OUnoObject,NULL);
     // get step property
     sal_Int32 nStep = 0;
-    OSL_ENSURE(0,"Who called me!");
+    OSL_FAIL("Who called me!");
     return nStep;
 }
 
@@ -749,11 +747,6 @@ void OUnoObject::NbcMove( const Size& rSize )
 
             // LLA: why there exists getPositionX and getPositionY and NOT getPosition() which return a Point?
             int nNewX = m_xReportComponent->getPositionX() + rSize.A();
-            // can this hinder us to set components outside the area?
-            // if (nNewX < 0)
-            // {
-            //     nNewX = 0;
-            // }
             m_xReportComponent->setPositionX(nNewX);
             int nNewY = m_xReportComponent->getPositionY() + rSize.B();
             if (nNewY < 0 && !bUndoMode)
@@ -766,14 +759,7 @@ void OUnoObject::NbcMove( const Size& rSize )
         }
         if (bPositionFixed)
         {
-            // OReportModel* pRptModel = static_cast<OReportModel*>(GetModel());
-            // if ( pRptModel )
-            // {
-            //    if (! pRptModel->GetUndoEnv().IsLocked())
-            //    {
-                    GetModel()->AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoMoveObject(*this, aUndoSize));
-            //    }
-            // }
+            GetModel()->AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoMoveObject(*this, aUndoSize));
         }
         // set geometry properties	
         SetPropsFromRect(GetLogicRect());
@@ -956,16 +942,16 @@ uno::Reference< uno::XInterface > OUnoObject::getUnoShape()
     return OObjectBase::getUnoShapeOf( *this );
 }
 // -----------------------------------------------------------------------------
-SdrObject* OUnoObject::Clone() const
+OUnoObject* OUnoObject::Clone() const
 {
-    SdrObject* pClone = SdrUnoObj::Clone();
+    OUnoObject* pClone = CloneHelper< OUnoObject >();
     if ( pClone )
     {
         Reference<XPropertySet> xSource(const_cast<OUnoObject*>(this)->getUnoShape(),uno::UNO_QUERY);
         Reference<XPropertySet> xDest(pClone->getUnoShape(),uno::UNO_QUERY);
         if ( xSource.is() && xDest.is() )
             comphelper::copyProperties(xSource.get(),xDest.get());
-    } // if ( pClone )
+    }
     return pClone;
 }
 //----------------------------------------------------------------------------
@@ -973,7 +959,7 @@ SdrObject* OUnoObject::Clone() const
 //----------------------------------------------------------------------------
 TYPEINIT1(OOle2Obj, SdrOle2Obj);
 DBG_NAME( rpt_OOle2Obj );
-OOle2Obj::OOle2Obj(const uno::Reference< report::XReportComponent>& _xComponent,UINT16 _nType)
+OOle2Obj::OOle2Obj(const uno::Reference< report::XReportComponent>& _xComponent,sal_uInt16 _nType)
           :SdrOle2Obj()
           ,OObjectBase(_xComponent)
           ,m_nType(_nType)
@@ -985,7 +971,7 @@ OOle2Obj::OOle2Obj(const uno::Reference< report::XReportComponent>& _xComponent,
     m_bIsListening = sal_True;
 }
 //----------------------------------------------------------------------------
-OOle2Obj::OOle2Obj(const ::rtl::OUString& _sComponentName,UINT16 _nType)
+OOle2Obj::OOle2Obj(const ::rtl::OUString& _sComponentName,sal_uInt16 _nType)
           :SdrOle2Obj()
           ,OObjectBase(_sComponentName)
           ,m_nType(_nType)
@@ -1000,12 +986,12 @@ OOle2Obj::~OOle2Obj()
     DBG_DTOR( rpt_OOle2Obj, NULL);
 }
 // -----------------------------------------------------------------------------
-UINT16 OOle2Obj::GetObjIdentifier() const
+sal_uInt16 OOle2Obj::GetObjIdentifier() const
 {
     return m_nType;
 }
 //----------------------------------------------------------------------------
-UINT32 OOle2Obj::GetObjInventor() const
+sal_uInt32 OOle2Obj::GetObjInventor() const
 {
     return ReportInventor;
 }
@@ -1027,7 +1013,7 @@ sal_Int32 OOle2Obj::GetStep() const
     DBG_CHKTHIS( rpt_OOle2Obj,NULL);
     // get step property
     sal_Int32 nStep = 0;
-    OSL_ENSURE(0,"Who called me!");
+    OSL_FAIL("Who called me!");
     return nStep;
 }
 
@@ -1139,14 +1125,14 @@ uno::Reference< chart2::data::XDatabaseDataProvider > lcl_getDataProvider(const
         {
             xSource.set(xChartDoc->getDataProvider(),uno::UNO_QUERY);
         }
-    } // if( xCompSupp.is())
+    }
     return xSource;
 }
 // -----------------------------------------------------------------------------
 // Clone() soll eine komplette Kopie des Objektes erzeugen.
-SdrObject* OOle2Obj::Clone() const
+OOle2Obj* OOle2Obj::Clone() const
 {
-    OOle2Obj* pObj = static_cast<OOle2Obj*>(SdrOle2Obj::Clone());
+    OOle2Obj* pObj = CloneHelper< OOle2Obj >();
     OReportModel* pRptModel = static_cast<OReportModel*>(GetModel());
     svt::EmbeddedObjectRef::TryRunningState( pObj->GetObjRef() );
     pObj->impl_createDataProvider_nothrow(pRptModel->getReportDefinition().get());
@@ -1175,7 +1161,7 @@ void OOle2Obj::impl_createDataProvider_nothrow(const uno::Reference< frame::XMod
             uno::Reference< lang::XMultiServiceFactory> xFac(_xModel,uno::UNO_QUERY);
             uno::Reference< chart2::data::XDatabaseDataProvider > xDataProvider( xFac->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.chart2.data.DataProvider"))),uno::UNO_QUERY);
             xReceiver->attachDataProvider( xDataProvider.get() );
-        } // if( xReceiver.is() )
+        }
     }
     catch(uno::Exception)
     {
