@@ -50,8 +50,6 @@ namespace rptui
 
     using namespace ::com::sun::star;
 
-    // const OReportController *& m_pReportController;
-
 DECLARE_STL_USTRINGACCESS_MAP(bool, AllProperties);
 DECLARE_STL_STDKEY_MAP(uno::Reference< beans::XPropertySet >, AllProperties, PropertySetInfoCache);
 
@@ -111,31 +109,6 @@ public:
         if ( _pEvt )
         {
             sal_Int32 nEvent = _pEvt->GetId();
-            /*
-              // just for debug
-            if (nEvent == VCLEVENT_WINDOW_CHILDCREATED ||
-                nEvent == VCLEVENT_WINDOW_PAINT ||
-                nEvent == VCLEVENT_WINDOW_MOVE ||
-                nEvent == VCLEVENT_WINDOW_RESIZE ||
-                nEvent == VCLEVENT_WINDOW_SHOW ||
-                nEvent == VCLEVENT_WINDOW_MOUSEMOVE ||
-                nEvent == VCLEVENT_WINDOW_FRAMETITLECHANGED || 
-                nEvent == VCLEVENT_WINDOW_HIDE ||
-                nEvent == VCLEVENT_EDIT_MODIFY ||
-                nEvent == VCLEVENT_SCROLLBAR_ENDSCROLL ||
-                nEvent == VCLEVENT_EDIT_SELECTIONCHANGED ||
-                nEvent == VCLEVENT_TABPAGE_INSERTED ||
-                nEvent == VCLEVENT_TABPAGE_REMOVED ||
-                nEvent == VCLEVENT_TOOLBOX_FORMATCHANGED ||
-                nEvent == VCLEVENT_TOOLBOX_ITEMADDED ||
-                nEvent == VCLEVENT_TOOLBOX_ALLITEMCHANGED ||
-                nEvent == VCLEVENT_MENUBARADDED ||
-                nEvent == 1
-                )
-            {
-                return 0L;
-            }
-            */
             
             if (nEvent == VCLEVENT_APPLICATION_DATACHANGED )
             {
@@ -146,8 +119,6 @@ public:
                 {
                     OEnvLock aLock(*this);
                     
-                    // sal_uInt32 nCount = m_pImpl->m_aSections.size();
-                    
                     // send all Section Objects a 'tingle'
                     // maybe they need a change in format, color, etc
                     ::std::vector< uno::Reference< container::XChild > >::const_iterator aIter = m_pImpl->m_aSections.begin();
@@ -200,7 +171,6 @@ public:
     void OXReportControllerObserver::Clear()
     {
         OEnvLock aLock(*this);
-        // sal_uInt32 nDebugValue = m_pImpl->m_aSections.size();
         m_pImpl->m_aSections.clear();
     }
     
@@ -316,7 +286,6 @@ void OXReportControllerObserver::switchListening( const uno::Reference< containe
 
         // be notified of any changes in the container elements
         uno::Reference< container::XContainer > xSimpleContainer( _rxContainer, uno::UNO_QUERY );
-        // OSL_ENSURE( xSimpleContainer.is(), "OXReportControllerObserver::switchListening: how are we expected to be notified of changes in the container?" );
         if ( xSimpleContainer.is() )
         {
             if ( _bStartListening )
@@ -368,17 +337,13 @@ void OXReportControllerObserver::switchListening( const uno::Reference< uno::XIn
 //------------------------------------------------------------------------------
 void SAL_CALL OXReportControllerObserver::modified( const lang::EventObject& /*aEvent*/ ) throw (uno::RuntimeException)
 {
-    // implSetModified();
 }
 
 //------------------------------------------------------------------------------
 void OXReportControllerObserver::AddElement(const uno::Reference< uno::XInterface >& _rxElement )
 {
-    // if ( !IsLocked() )
-    // {
     m_aFormattedFieldBeautifier.notifyElementInserted(_rxElement);
     m_aFixedTextColor.notifyElementInserted(_rxElement);
-    // }
     
     // if it's a container, start listening at all elements
     uno::Reference< container::XIndexAccess > xContainer( _rxElement, uno::UNO_QUERY );
