@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -84,7 +85,7 @@ sal_Int32 lcl_getOverlappedControlColor(/*const uno::Reference <lang::XMultiServ
 }
 //------------------------------------------------------------------------------
 DBG_NAME( rpt_OReportSection )
-OReportSection::OReportSection(OSectionWindow* _pParent,const uno::Reference< report::XSection >& _xSection) 
+OReportSection::OReportSection(OSectionWindow* _pParent,const uno::Reference< report::XSection >& _xSection)
 : Window(_pParent,WB_DIALOGCONTROL)
 , ::comphelper::OPropertyChangeListener(m_aMutex)
 , DropTargetHelper(this)
@@ -96,46 +97,44 @@ OReportSection::OReportSection(OSectionWindow* _pParent,const uno::Reference< re
 ,m_pReportListener(NULL)
 ,m_xSection(_xSection)
 ,m_eMode(RPTUI_SELECT)
-,m_bDialogModelChanged(FALSE)
+,m_bDialogModelChanged(sal_False)
 ,m_bInDrag(sal_False)
 {
     DBG_CTOR( rpt_OReportSection,NULL);
     EnableChildTransparentMode();
     SetHelpId(HID_REPORTSECTION);
     SetMapMode( MapMode( MAP_100TH_MM ) );
-   
+
     try
     {
         fill();
     }
     catch(uno::Exception&)
     {
-        OSL_ENSURE(0,"Exception catched!");
+        OSL_FAIL("Exception catched!");
     }
 
     m_pFunc.reset(new DlgEdFuncSelect( this ));
-    m_pFunc->setOverlappedControlColor(lcl_getOverlappedControlColor( /* m_pParent->getViewsWindow()->getView()->getReportView()->getController().getORB() */ ) );
+    m_pFunc->setOverlappedControlColor(lcl_getOverlappedControlColor() );
 }
 //------------------------------------------------------------------------------
 OReportSection::~OReportSection()
 {
     DBG_DTOR( rpt_OReportSection,NULL);
     m_pPage = NULL;
-    //m_pModel->GetUndoEnv().RemoveSection(m_xSection.get());
     if ( m_pMulti.is() )
         m_pMulti->dispose();
-    
+
     if ( m_pReportListener.is() )
         m_pReportListener->dispose();
     m_pFunc = ::std::auto_ptr<DlgEdFunc>();
-    
+
     {
         ::std::auto_ptr<OSectionView> aTemp( m_pView);
         if ( m_pView )
             m_pView->EndListening( *m_pModel );
         m_pView = NULL;
     }
-    /*m_pModel->DeletePage(m_pPage->GetPageNum());*/
 }
 //------------------------------------------------------------------------------
 void OReportSection::Paint( const Rectangle& rRect )
@@ -211,7 +210,7 @@ void OReportSection::fill()
     // without the following call, no grid is painted
     m_pView->ShowSdrPage( m_pPage );
 
-    m_pView->SetMoveSnapOnlyTopLeft( TRUE );
+    m_pView->SetMoveSnapOnlyTopLeft( sal_True );
     ODesignView* pDesignView = m_pParent->getViewsWindow()->getView()->getReportView();
 
     // #i93595# Adapted grid to a more coarse grid and subdivisions for better visualisation. This
@@ -226,9 +225,9 @@ void OReportSection::fill()
     const Fraction aY(aGridSizeFine.B());
     m_pView->SetSnapGridWidth(aX, aY);
 
-    m_pView->SetGridSnap( pDesignView->isGridSnap() );	
-    m_pView->SetGridFront( FALSE );
-    m_pView->SetDragStripes( TRUE );
+    m_pView->SetGridSnap( pDesignView->isGridSnap() );
+    m_pView->SetGridFront( sal_False );
+    m_pView->SetDragStripes( sal_True );
     m_pView->SetPageVisible();
     sal_Int32 nColor = m_xSection->getBackColor();
     if ( nColor == (sal_Int32)COL_TRANSPARENT )
@@ -243,10 +242,9 @@ void OReportSection::fill()
 // LLA: TODO
 //  m_pPage->SetUppBorder(-10000);
 
-    m_pView->SetDesignMode( TRUE );	
+    m_pView->SetDesignMode( sal_True );	
 
     m_pView->StartListening( *m_pModel  );
-    /*Resize();*/
     if ( m_xSection.is() && m_pPage && m_pView )
     {
         uno::Reference<report::XReportDefinition> xReportDefinition = m_xSection->getReportDefinition();
@@ -255,9 +253,7 @@ void OReportSection::fill()
         const sal_Int32 nWorkAreaLeftMargin = getStyleProperty<sal_Int32>(xReportDefinition,PROPERTY_LEFTMARGIN);
         const sal_Int32 nWorkAreaRightMargin = getStyleProperty<sal_Int32>(xReportDefinition,PROPERTY_RIGHTMARGIN);
         m_pView->SetWorkArea( Rectangle( Point( nWorkAreaLeftMargin, 0), Size(aPageSize.Width() - nWorkAreaLeftMargin - nWorkAreaRightMargin,aPageSize.Height()) ) );
-    } // if ( m_xSection.is() && m_pPage && m_pView )
-
-    //SetBackground( Wallpaper( COL_BLUE ));
+    }
 }
 // -----------------------------------------------------------------------------
 void OReportSection::Paste(const uno::Sequence< beans::NamedValue >& _aAllreadyCopiedObjects,bool _bForce)
@@ -289,7 +285,7 @@ void OReportSection::Paste(const uno::Sequence< beans::NamedValue >& _aAllreadyC
                         SvxShape* pShape = SvxShape::getImplementation( *pCopiesIter );
                         SdrObject* pObject = pShape ? pShape->GetSdrObject() : NULL;
                         if ( pObject )
-                        {   
+                        {
                             SdrObject* pNeuObj = pObject->Clone();
 
                             pNeuObj->SetPage( m_pPage );
@@ -308,7 +304,6 @@ void OReportSection::Paste(const uno::Sequence< beans::NamedValue >& _aAllreadyC
                                 {
                                     aRet.Move(0,aRet.getHeight()+1);
                                     pNeuObj->SetLogicRect(aRet);
-                                    //(*pCopiesIter)->setPositionY(aRet.Top());
                                 }
                             }
                             m_pView->AddUndo( m_pView->GetModel()->GetSdrUndoFactory().CreateUndoNewObject( *pNeuObj ) );
@@ -320,7 +315,7 @@ void OReportSection::Paste(const uno::Sequence< beans::NamedValue >& _aAllreadyC
                 }
                 catch(uno::Exception&)
                 {
-                    OSL_ENSURE(0,"Exception caught while pasting a new object!");
+                    OSL_FAIL("Exception caught while pasting a new object!");
                 }
                 if ( !_bForce )
                     break;
@@ -353,33 +348,30 @@ void OReportSection::SetMode( DlgEdMode eNewMode )
         m_pFunc->setOverlappedControlColor(lcl_getOverlappedControlColor( ) );
         m_pModel->SetReadOnly(eNewMode == RPTUI_READONLY);
         m_eMode = eNewMode;
-    }	
+    }
 }
 // -----------------------------------------------------------------------------
 void OReportSection::Copy(uno::Sequence< beans::NamedValue >& _rAllreadyCopiedObjects)
-{	
+{
     Copy(_rAllreadyCopiedObjects,false);
 }
 //----------------------------------------------------------------------------
 void OReportSection::Copy(uno::Sequence< beans::NamedValue >& _rAllreadyCopiedObjects,bool _bEraseAnddNoClone)
-{	
+{
     OSL_ENSURE(m_xSection.is(),"Why is the section here NULL!");
     if( !m_pView->AreObjectsMarked() || !m_xSection.is() )
         return;
 
-    // stop all drawing actions
-    //m_pView->BrkAction();
-
     // insert control models of marked objects into clipboard dialog model
     const SdrMarkList& rMarkedList = m_pView->GetMarkedObjectList();
-    const ULONG nMark = rMarkedList.GetMarkCount();
+    const sal_uLong nMark = rMarkedList.GetMarkCount();
 
     ::std::vector< uno::Reference<report::XReportComponent> > aCopies;
     aCopies.reserve(nMark);
 
     SdrUndoFactory& rUndo = m_pView->GetModel()->GetSdrUndoFactory();
-    
-    for( ULONG i = nMark; i > 0; )
+
+    for( sal_uLong i = nMark; i > 0; )
     {
         --i;
         SdrObject* pSdrObject = rMarkedList.GetMark(i)->GetMarkedSdrObj();
@@ -399,10 +391,10 @@ void OReportSection::Copy(uno::Sequence< beans::NamedValue >& _rAllreadyCopiedOb
             }
             catch(uno::Exception&)
             {
-                OSL_ENSURE(0,"Can't copy report elements!");
+                OSL_FAIL("Can't copy report elements!");
             }
         }
-    } // for( ULONG i = 0; i < nMark; i++ )
+    }
 
     if ( !aCopies.empty() )
     {
@@ -436,7 +428,7 @@ void OReportSection::MouseMove( const MouseEvent& rMEvt )
 
 }
 //----------------------------------------------------------------------------
-void OReportSection::SetGridVisible(BOOL _bVisible)
+void OReportSection::SetGridVisible(sal_Bool _bVisible)
 {
     m_pView->SetGridVisible( _bVisible );
 }
@@ -451,32 +443,36 @@ void OReportSection::SelectAll(const sal_uInt16 _nObjectType)
         {
             m_pView->UnmarkAll();
             SdrObjListIter aIter(*m_pPage,IM_DEEPNOGROUPS);
-            SdrObject* pObjIter = NULL;        
+            SdrObject* pObjIter = NULL;
             while( (pObjIter = aIter.Next()) != NULL )
             {
                 if ( pObjIter->GetObjIdentifier() == _nObjectType )
                     m_pView->MarkObj( pObjIter, m_pView->GetSdrPageView() );
             }
-        }		
+        }
     }
 }
-void lcl_insertMenuItemImages(PopupMenu& rContextMenu,OReportController& rController,const uno::Reference< report::XReportDefinition>& _xReportDefinition,uno::Reference<frame::XFrame>& _rFrame,BOOL _bHiContrast)
+void lcl_insertMenuItemImages(
+    PopupMenu& rContextMenu,
+    OReportController& rController,
+    const uno::Reference< report::XReportDefinition>& _xReportDefinition,uno::Reference<frame::XFrame>& _rFrame
+)
 {
-    const USHORT nCount = rContextMenu.GetItemCount();
-    for (USHORT i = 0; i < nCount; ++i)
+    const sal_uInt16 nCount = rContextMenu.GetItemCount();
+    for (sal_uInt16 i = 0; i < nCount; ++i)
     {
         if ( MENUITEM_SEPARATOR != rContextMenu.GetItemType(i))
         {
-            const USHORT nId = rContextMenu.GetItemId(i);
+            const sal_uInt16 nId = rContextMenu.GetItemId(i);
             PopupMenu* pPopupMenu = rContextMenu.GetPopupMenu( nId );
             if ( pPopupMenu )
             {
-                lcl_insertMenuItemImages(*pPopupMenu,rController,_xReportDefinition,_rFrame,_bHiContrast);
+                lcl_insertMenuItemImages(*pPopupMenu,rController,_xReportDefinition,_rFrame);
             }
             else
             {
                 const ::rtl::OUString sCommand = rContextMenu.GetItemCommand(nId);
-                rContextMenu.SetItemImage(nId,framework::GetImageFromURL(_rFrame,sCommand,FALSE,_bHiContrast));
+                rContextMenu.SetItemImage(nId,framework::GetImageFromURL(_rFrame,sCommand,sal_False));
                 if ( nId == SID_PAGEHEADERFOOTER )
                 {
                     String sText = String(ModuleRes((_xReportDefinition.is() && _xReportDefinition->getPageHeaderOn()) ? RID_STR_PAGEHEADERFOOTER_DELETE : RID_STR_PAGEHEADERFOOTER_INSERT));
@@ -491,7 +487,7 @@ void lcl_insertMenuItemImages(PopupMenu& rContextMenu,OReportController& rContro
             rContextMenu.CheckItem(nId,rController.isCommandChecked(nId));
             rContextMenu.EnableItem(nId,rController.isCommandEnabled(nId));
         }
-    } // for (USHORT i = 0; i < nCount; ++i)
+    }
 }
 //----------------------------------------------------------------------------
 void OReportSection::Command( const CommandEvent& _rCEvt )
@@ -501,18 +497,16 @@ void OReportSection::Command( const CommandEvent& _rCEvt )
     {
         case COMMAND_CONTEXTMENU:
         {
-            const StyleSettings& rSettings = Application::GetSettings().GetStyleSettings();
-            BOOL bHiContrast = rSettings.GetHighContrastMode();
             OReportController& rController = m_pParent->getViewsWindow()->getView()->getReportView()->getController();
             uno::Reference<frame::XFrame> xFrame = rController.getFrame();
-            PopupMenu aContextMenu( ModuleRes( RID_MENU_REPORT ) );			
+            PopupMenu aContextMenu( ModuleRes( RID_MENU_REPORT ) );
             uno::Reference< report::XReportDefinition> xReportDefinition = getSection()->getReportDefinition();
-            
-            lcl_insertMenuItemImages(aContextMenu,rController,xReportDefinition,xFrame,bHiContrast);
+
+            lcl_insertMenuItemImages(aContextMenu,rController,xReportDefinition,xFrame);
 
             Point aPos = _rCEvt.GetMousePosPixel();
             m_pView->EndAction();
-            const USHORT nId = aContextMenu.Execute(this, aPos);
+            const sal_uInt16 nId = aContextMenu.Execute(this, aPos);
             if ( nId )
             {
                 uno::Sequence< beans::PropertyValue> aArgs;
@@ -594,7 +588,7 @@ void OReportSection::_propertyChanged(const beans::PropertyChangeEvent& _rEvent)
                         }
                         if ( aPos.Y < 0 )
                             aPos.Y = 0;
-                        if ( bChanged ) 
+                        if ( bChanged )
                         {
                             xReportComponent->setPosition(aPos);
                             correctOverlapping(pObject,*this,false);
@@ -606,16 +600,16 @@ void OReportSection::_propertyChanged(const beans::PropertyChangeEvent& _rEvent)
                         }
                         pBase->StartListening();
                     }
-                } // for (sal_Int32 i = 0; i < nCount; ++i)
+                }
             }
             catch(uno::Exception)
             {
-                OSL_ENSURE(0,"Exception caught: OReportSection::_propertyChanged(");
+                OSL_FAIL("Exception caught: OReportSection::_propertyChanged(");
             }
 
             Resize();
         }
-    }	
+    }
 }
 //------------------------------------------------------------------------------
 sal_Bool OReportSection::handleKeyEvent(const KeyEvent& _rEvent)
@@ -631,7 +625,7 @@ void OReportSection::deactivateOle()
 // -----------------------------------------------------------------------------
 void OReportSection::createDefault(const ::rtl::OUString& _sType)
 {
-    SdrObject* pObj = m_pView->GetCreateObj();//rMarkList.GetMark(0)->GetObj();
+    SdrObject* pObj = m_pView->GetCreateObj();
     if ( !pObj )
         return;
     createDefault(_sType,pObj);
@@ -732,7 +726,11 @@ void OReportSection::fillControlModelSelection(::std::vector< uno::Reference< un
             const SdrObject* pDlgEdObj = rMarkList.GetMark(i)->GetMarkedSdrObj();
             const OObjectBase* pObj = dynamic_cast<const OObjectBase*>(pDlgEdObj);
             if ( pObj )
-                _rSelection.push_back(pObj->getReportComponent());
+            {
+                uno::Reference<uno::XInterface> xInterface =
+                    pObj->getReportComponent();
+                _rSelection.push_back(xInterface);
+            }
         }
     }
 }
@@ -751,7 +749,7 @@ sal_Int8 OReportSection::AcceptDrop( const AcceptDropEvent& _rEvt )
          )
     {
         if (!m_pParent) return DND_ACTION_NONE;
-        USHORT nCurrentPosition = 0;
+        sal_uInt16 nCurrentPosition = 0;
         nCurrentPosition = m_pParent->getViewsWindow()->getPosition(m_pParent);
         if (_rEvt.mnAction == DND_ACTION_COPY )
         {
@@ -778,7 +776,7 @@ sal_Int8 OReportSection::AcceptDrop( const AcceptDropEvent& _rEvt )
         if (   ::svx::OMultiColumnTransferable::canExtractDescriptor(rFlavors)
             || ::svx::OColumnTransferable::canExtractColumnDescriptor(rFlavors, CTF_FIELD_DESCRIPTOR | CTF_CONTROL_EXCHANGE | CTF_COLUMN_DESCRIPTOR) )
             return _rEvt.mnAction;
-        
+
         const sal_Int8 nDropOption = ( OReportExchange::canExtract(rFlavors) ) ? DND_ACTION_COPYMOVE : DND_ACTION_NONE;
 
         return nDropOption;
@@ -806,8 +804,7 @@ sal_Int8 OReportSection::ExecuteDrop( const ExecuteDropEvent& _rEvt )
         nDropOption = DND_ACTION_COPYMOVE;
         m_pParent->getViewsWindow()->BrkAction();
         m_pParent->getViewsWindow()->unmarkAllObjects(m_pView);
-        //m_pParent->getViewsWindow()->getView()->setMarked(m_pView,sal_True);
-    } // if ( OReportExchange::canExtract(rFlavors) )
+    }
     else if ( bMultipleFormat
         || ::svx::OColumnTransferable::canExtractColumnDescriptor(rFlavors, CTF_FIELD_DESCRIPTOR | CTF_CONTROL_EXCHANGE | CTF_COLUMN_DESCRIPTOR) )
     {
@@ -826,13 +823,13 @@ sal_Int8 OReportSection::ExecuteDrop( const ExecuteDropEvent& _rEvt )
         if ( !bMultipleFormat )
         {
             ::svx::ODataAccessDescriptor aDescriptor = ::svx::OColumnTransferable::extractColumnDescriptor(aDropped);
-            
+
             aValues.realloc(1);
             aValues[0].Value <<= aDescriptor.createPropertyValueSequence();
-        } // if ( !bMultipleFormat )
-        else 
+        }
+        else
             aValues = ::svx::OMultiColumnTransferable::extractDescriptor(aDropped);
-        
+
         beans::PropertyValue* pIter = aValues.getArray();
         beans::PropertyValue* pEnd  = pIter + aValues.getLength();
         for(;pIter != pEnd; ++pIter)
@@ -845,7 +842,7 @@ sal_Int8 OReportSection::ExecuteDrop( const ExecuteDropEvent& _rEvt )
                 aCurrent.realloc(nLength + 3);
                 aCurrent[nLength].Name = PROPERTY_POSITION;
                 aCurrent[nLength++].Value <<= AWTPoint(aDropPos);
-                // give also the DND Action (Shift|Ctrl) Key to really say what we want 
+                // give also the DND Action (Shift|Ctrl) Key to really say what we want
                 aCurrent[nLength].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DNDAction"));
                 aCurrent[nLength++].Value <<= _rEvt.mnAction;
 
@@ -876,3 +873,5 @@ bool OReportSection::isUiActive() const
 // =============================================================================
 }
 // =============================================================================
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
